Returns the boundaries for any group sequential test of the null vs. 2-sided alternative whose boundaries take the form of a single constant times a known weight vector, which is w.vec. These include Pocock (w.vec=(1,1,..)), O'Brien-Fleming (w.vec=(sqrt(n.stg/1), sqrt(n.stg/2), ..., 1)), etc. It does this by returning quantiles of the sample paths of the (null) test statistic paths in mc.paths.
bdr.gs.mc.gen(alpha = 0.05, mc.paths, w.vec)Returns a list:
the constant in the boundary vector cons*w.vec
the boundary vector cons*w.vec
desired rejection probability of the test; default is 0.05
matrix of sample paths, each row being a sample path, no. of columns is number of stages
weight vector corresponding to desired test
Jay Bartroff