Compute the operating characteristics on the group sequential test with futility stopping statistics in paths: The expected stopping stage no., plus the probability of rejecting the null in favor of the 2-sided alternative. This is for a general GS test which uses the boundaries in bndry.vec.
op.char.gs.fut(b.vec, a.vec, paths)Returns a list:
expected stopping stage number
standard error of stopping time
prob. of rejecting the null (at any stage)
"null-rejection" boundaries, should be >= 0, and a.vec[n.stg] = b.vec[n.stg].
futility boundaries, should be >= 0, and a.vec[n.stg] = b.vec[n.stg];a.vec[j]=0 means no futility stopping at stage j.
matrix of test statistic sample paths, each row being a sample path, no. of columns is max number